pro goes3sec_copy, date0, date1, week=week, last_24hrs=last_24hrs, $
       qdebug=qdebug, infil=infil, mk_week_file=mk_week_file, $
       only_week=only_week
;+
;   Name: goes3sec_copy
;
;   Purpose: copy 3 second data from selsis - optionally make week file
;   
;   Input Parameters:
;      date0 - start day for copy (default is today or via WEEK keyword)
;      date1 - stop day for copy  (stop day - default is 24 hours from date0)
;
;   Keyword Parameters:
;      week -         string of form 'YY_WW' can be used instead of date0/date1
;      last_24hrs - if set, date0=yesterday, date1=today
;
;   Calling Examples:
;      goes3sec_copy,date			; copy files for date (UT)
;      goes3sec_copy,week='95_13',/mk_week	; files for week / make gxd file
;
;HISTORY:
;	Written by M.Morrison
;	25-Mar-93 (MDM) - Modified to use DECNET "dcp" command instead
;			  of FTP since there were computer problems at Boulder
;	16-Apr-93 (MDM) - Modified to re-copy when the file size of the existing
;			  file is less than 70,000 bytes (should be 70600 or 70620
;			  when properly copied)
;			- went back to using FTP
;			- Added INFIL option
;	12-May-93 (MDM) - Correct for case where there are no existing files
;			- Added /MK_WEEK_FILE option
;	14-May-93 (MDM) - Changed to use $ydb_raw and $ys
;	16-May-93 (MDM) - The MK_WEEK_FILE option was not working for Saturdays
;			  because it was using the wrong time.
;	17-May-93 (MDM) - Changed how MK_WEEK_FILE option worked
;       26-May-93 (MDM0 - Changed to use /ys/site/script instead of /ys/gen/script
;        19-Aug-93 (MDM) - Removed /self switch from Mail call
;	  4-Jan-94 (MDM) - Modified mailing list
;        11-apr-95 (SLF) - cleaned up / use GOES3_FTP_NODE env
;        13-apr-95 (SLF) - major rewrite of date code using timegrid / ftp_copy
;                          dont bother with goes6 after date='17-aug-94'
;			   add WEEK keyword and function - eliminte dcp stuff
;        29-jun-95 (SLF) - remove software from mailing list
;        29-aug-95 (SLF) - cleaned up some "ss" logic
;        30-aug-95 (SLF) - generate 1 and 5 minute average files after GxD.
;        20-mar-96 (SLF) - add GOES9
;        27-mar-96 (SLF) - and GOES8
;        13-aug-96 (SLF) - GOES7 turn-off fixup (14-aug-96)
;        20-sep-96 (SLF) - fix typo in last_24hrs keyword 
;        21-Jul-98 (SLF) - add GOES10
;        19-oct-98 (SLF) - inhibit week files for goes10 (mk_week_file prob)
;-
; -----------------------------------------------------------
outdir= concat_dir(get_logenv('ydb_raw'),'goes3sec_raw')
logdir  = get_logenv('DIR_SITE_SCRIPT')
ftp_fil = concat_dir(logdir, 'goes3sec_copy.ftp')
; ----------------------------------------------------------
;
; ----------------------------------------------------------------------
; slf - 13-apr-1995 - clean up time logic via timegrid / allow time range

now=ut_time()
today=     gt_day(now,/string) 				; today in UT
yesterday= gt_day(timegrid(today,day=-1),/string)	; yesterday in UT
fpd=8							; files per day

case 1 of 
   keyword_set(week): begin				; week = 'YY_WW'
      sweek=str2arr(week,'_')
      pr_week2tim,fix(sweek(1)),year=fix(sweek(0)),date0,date1
      tims=timegrid(date0,timegrid(date1,hours=23,/string),hours=3,/string)
   endcase
   keyword_set(last_24hrs): tims=timegrid(yesterday,now,hours=3,/string)
   n_params() eq 0: tims=timegrid(today,now,hours=3,nsamp=fpd,/str)
   n_params() eq 1: tims=timegrid(gt_day(date0,/str),hours=3,nsamp=fpd,/string)
   n_params() eq 2: tims=timegrid(date0,date1,hours=3)
endcase
; ------------------------------------------------------------------
trim=sel_timrange(tims,tims(0),now,/between)

if trim(0) eq -1 then begin
  message,/info,"No files availble for input times
  return
endif else tims=tims(trim)
;
; dont bother with GOES 6 after it's demise 
fids = ex2fid( anytim2ex(tims) )
filnam=''
get7=int2secarr(anytim2ints(tims(0)),'14-aug-96') lt 0
if get7 then filnam=[filnam,'go07' + fids]
get6=int2secarr(anytim2ints(tims(0)),'17-aug-94') lt 0
if get6 then filnam=['go06' + fids,filnam]
get9=int2secarr(anytim2ints(tims(0)),'20-mar-96') ge 0
if get9 then filnam=['go09' + fids,filnam]
get8=int2secarr(anytim2ints(tims(0)),'21-mar-96') ge 0
if get8 then filnam=['go08' + fids,filnam]
get10=int2secarr(anytim2ints(tims(0)),'18-jul-98') ge 0
if get10 then filnam=['go10' + fids,filnam]

filnam=filnam(1:*)
;
if (keyword_set(infil)) then begin
    break_file, infil, dsk_log, dir00, filnam, ext
    filnam = filnam + ext
end

outfil1  = concat_dir(outdir, filnam)
allfile  = outfil1
;

box_message,'runnin mirror...'
mircmd=[concat_dir('$SSW','gen/mirror/mirror'), $
        concat_dir('$SSW_SITE_MIRROR','goes3sec.mirror')]
spawn,mircmd,/noshell,mirout
;
; delete zero block files

ssg=where(filnam ne '',sscnt)
; ---------- make week file on request ---------------
if keyword_set(mk_week_file)  then begin
    files=file_list(outdir,'go????????.??00')
    break_file,files,ll,pp,ff,ee,vv
    filnam=ff+ee

    tarr = fid2ex(strmid(filnam, 4, 11))
    wids = ex2week(tarr, /wid, /get_uniq)
  gsat=[                      $
         (['','6'])(get6),      $
         (['','7'])(get7),      $
         (['','8'])(get8),      $
         (['','9'])(get9),      $ 
         (['','0'])(get10)] 
    which =where(gsat ne '',wcnt)
    if wcnt eq 0 then begin
       message,/info,"No week files to generate...."
       return
    endif
    gsat=gsat(which)

    prefix='g' + str_perm(gsat,['d','1','5'])	; all prefixes (D,1,5)

    wids=last_nelem(wids,2)
    for i=0,n_elements(wids)-1 do $
       for j=0,n_elements(prefix)-1 do begin
          message,/info,"mk_week_file," + prefix(j) + ",week=" + wids(i)
          mk_week_file, prefix(j), week=wids(i)
       endfor
end
;
end

