pro rd_goes3sec, infil, header, data, outrec=outrec, rm_bad=rm_bad
;
;+
;NAME:
;	rd_goes3sec
;PURPOSE:
;	Read the raw GOES 3 sec data file
;INPUT:
;	infil	- The raw data file name(s)
;OPTIONAL KEYWORD INPUT:
;	rm_bad	- If set, then remove the bad datapoints (negative counts)
;OUTPUT:
;	header	- The header structure of that file
;	data	- The data within that file
;OPTIONAL KEYWORD OUTPUT:
;	outrec	- The Yohkoh data structure with the information in the
;		  data file.
;HISTORY:
;	Written Fall '92 by M.Morrison
;	15-Apr-93 (MDM) - Expanded to have OUTREC (to be used by MK_GX)
;-
;
;
header0 = {goes3sec_head, year: 0.0, doy: 0.0, satellite: 0.0, dummy: fltarr(2)}
data0   = {goes3sec_data, sec: 0.0, stat1: 0.0, stat2: 0.0, short: 0.0, long: 0.0}
;
nfil = n_elements(infil)
;
fsizes=file_size(infil)
nrec = total(fsizes)/20
ndrec = nrec - nfil
;
data = replicate(data0, ndrec)
header = replicate(header0, nfil)
;
gbo_struct, gxd_data=data_ref
outrec = replicate(data_ref, ndrec)
;
ii = 0
for ifil=0,nfil-1 do begin
    openr, lun, infil(ifil), /get_lun
    ;
    nn = fsizes(ifil)/20-1
    data00 = replicate(data0, nn)
    readu, lun, header0
    readu, lun, data00
    
    rev_swap,header0
    rev_swap,data00
    ;
    header(ifil) = header0
    data(ii:ii+nn-1) = data00
    free_lun, lun

    tarr = doytim2ex(string(header0.doy), year=header0.year)
    daytim = anytim2ints(tarr)
    tims = anytim2ints(replicate(daytim, nn), off=data00.sec)
    outrec(ii:ii+nn-1).time = tims.time
    outrec(ii:ii+nn-1).day  = tims.day
    outrec(ii:ii+nn-1).hi   = data00.short
    outrec(ii:ii+nn-1).lo   = data00.long
end
;
if (keyword_set(rm_bad)) then begin
    ss = where( (outrec.lo gt 0) and (outrec.hi gt 0) )
    if (ss(0) ne -1) then outrec = outrec(ss) $
	else outrec = 0b
end
;
end

